#![allow(dead_code)]
pub struct Abc<A> {
    field: A,
}

pub struct Def {
    field: u8,
}

pub struct Def2 {
    pub field: u8,
}

pub struct Efg {
    pub field: u8,
}

pub struct Fgh {
    field: u8,
}

pub struct Ghi {
    pub field: u8,
}

pub struct Hij(u8);

pub struct Iij {
    field: u16,
}
